Flags

Struct Flags 

pub struct Flags {
    pub response: bool,
    pub opcode: Opcode,
    pub authoritative: bool,
    pub truncated: bool,
    pub recursion_desired: bool,
    pub recursion_available: bool,
    pub authentic_data: bool,
    pub checking_disabled: bool,
    pub error_code: Option<ErrorCode>,
}
The flags that accompany every DNS packet.

Fields

response: bool

Whether this packet is a response packet.

opcode: Opcode

The operation being performed.

authoritative: bool

In a response, whether the server is providing authoritative DNS responses.

truncated: bool

In a response, whether this message has been truncated by the transport.

recursion_desired: bool

In a query, whether the server may query other nameservers recursively. It is up to the server whether it will actually do this.

recursion_available: bool

In a response, whether the server allows recursive query support.

authentic_data: bool

In a response, whether the server is marking this data as authentic.

checking_disabled: bool

In a request, whether the server should disable its authenticity checking for the request’s queries.

error_code: Option<ErrorCode>

In a response, a code indicating an error if one occurred.

Implementations

Source

impl Flags

pub fn query() -> Self

The set of flags that represents a query packet.

pub fn standard_response() -> Self

The set of flags that represents a successful response.

pub fn to_u16(self) -> u16

Converts the flags into a two-byte number.

pub fn from_u16(bits: u16) -> Self

Extracts the flags from the given two-byte number.