pub struct Flags {
pub response: bool,
pub opcode: Opcode,
pub authoritative: bool,
pub truncated: bool,
pub recursion_desired: bool,
pub recursion_available: bool,
pub authentic_data: bool,
pub checking_disabled: bool,
pub error_code: Option<ErrorCode>,
}Expand description
The flags that accompany every DNS packet.
Fields
response: boolWhether this packet is a response packet.
opcode: OpcodeThe operation being performed.
In a response, whether the server is providing authoritative DNS responses.
truncated: boolIn a response, whether this message has been truncated by the transport.
recursion_desired: boolIn a query, whether the server may query other nameservers recursively. It is up to the server whether it will actually do this.
recursion_available: boolIn a response, whether the server allows recursive query support.
authentic_data: boolIn a response, whether the server is marking this data as authentic.
checking_disabled: boolIn a request, whether the server should disable its authenticity checking for the request’s queries.
error_code: Option<ErrorCode>In a response, a code indicating an error if one occurred.
Implementations
Sourceimpl Flags
impl Flags
Sourcepub fn standard_response() -> Self
pub fn standard_response() -> Self
The set of flags that represents a successful response.